@@ -1,20 +1,14 @@
 //! Crypto errors.
-use blst::BLST_ERROR as BlstError;
-use ff::PrimeFieldDecodingError;
-
 use thiserror::Error;
 
-/// A crypto result.
-pub type Result<T> = ::std::result::Result<T, Error>;
-
 /// A crypto error.
 #[derive(Clone, Eq, PartialEq, Debug, Error)]
 pub enum Error {
     /// Not enough signature shares.
-    #[error("Not enough signature shares")]
+    #[error("Not enough shares for interpolation")]
     NotEnoughShares,
-    /// Signature shares contain a duplicated index.
-    #[error("Signature shares contain a duplicated index")]
+    /// Samples for interpolation contain a duplicated index.
+    #[error("Samples for interpolation contain a duplicated index")]
     DuplicateEntry,
     /// The degree is too high for the coefficients to be indexed by `usize`.
     #[error("The degree is too high for the coefficients to be indexed by usize.")]
@@ -22,29 +16,13 @@ pub enum Error {
     /// An error reading a structure from an array of bytes. Invalid bytes representation.
     #[error("Invalid bytes representation.")]
     InvalidBytes,
-    /// BLST error
-    #[error("BLST error: {0}")]
-    BlstError(String),
+    /// The result of Hash To Field is zero which should never happen.
+    #[error("Hash To Field returned zero")]
+    HashToFieldIsZero,
 }
 
-impl From<PrimeFieldDecodingError> for Error {
-    fn from(_: PrimeFieldDecodingError) -> Self {
-        Error::InvalidBytes
-    }
-}
-
-impl From<BlstError> for Error {
-    fn from(error: BlstError) -> Self {
-        if error == BlstError::BLST_SUCCESS {
-            Error::BlstError(format!(
-                "received inconsistent and unexpected result: {:?}",
-                error
-            ))
-        } else {
-            Error::BlstError(format!("{:?}", error))
-        }
-    }
-}
+/// A crypto result.
+pub type Result<T> = ::std::result::Result<T, Error>;
 
 #[cfg(test)]
 mod tests {
